@@ -6,12 +6,13 @@ import sys
 sys.path.insert(0, os.path.abspath(".."))
 
 import guidata  # noqa: E402
-from guidata.utils.genreqs import generate_requirement_tables  # noqa: E402
+from guidata.utils.genreqs import gen_module_req_rst  # noqa: E402
 
-generate_requirement_tables(guidata, ["Python>=3.7", "PyQt>=5.11"])
+gen_module_req_rst(guidata, ["Python>=3.7", "PyQt5>=5.11"])
 
+creator = "Pierre Raybaut"
 project = "guidata"
-copyright = "2009 CEA - Commissariat à l'Energie Atomique et aux Energies Alternatives"
+copyright = "2009 CEA, " + creator
 version = ".".join(guidata.__version__.split(".")[:2])
 release = guidata.__version__
 
@@ -19,10 +20,14 @@ extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.intersphinx",
     "sphinx.ext.doctest",
-    "sphinx.ext.mathjax",
     "sphinx_copybutton",
     "sphinx.ext.napoleon",
+    "sphinx_qt_documentation",
 ]
+if "htmlhelp" in sys.argv:
+    extensions += ["sphinx.ext.imgmath"]
+else:
+    extensions += ["sphinx.ext.mathjax"]
 templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
@@ -32,7 +37,17 @@ pygments_style = "sphinx"
 modindex_common_prefix = ["guidata."]
 autodoc_member_order = "bysource"
 
-html_theme = "classic"
+intersphinx_mapping = {
+    "python": ("https://docs.python.org/3", None),
+    "numpy": ("https://numpy.org/doc/stable/", None),
+    "h5py": ("https://docs.h5py.org/en/stable/", None),
+}
+# nitpicky = True  # Uncomment to warn about all broken links
+
+if "htmlhelp" in sys.argv:
+    html_theme = "classic"
+else:
+    html_theme = "python_docs_theme"
 html_title = "%s %s Manual" % (project, version)
 html_short_title = "%s Manual" % project
 html_logo = "images/guidata-vertical.png"
@@ -41,5 +56,5 @@ html_static_path = ["_static"]
 html_use_modindex = True
 htmlhelp_basename = "guidata"
 latex_documents = [
-    ("index", "guidata.tex", "guidata Manual", "Pierre Raybaut", "manual"),
+    ("index", "guidata.tex", "guidata Manual", creator, "manual"),
 ]
